parse_from_buffer

Function parse_from_buffer 

pub fn parse_from_buffer(buffer: &[u8]) -> Result<GBX, ParseError>
Parses the given slice of bytes as if it was a GBX file.

This function assumes the XML header included in the GBX file is valid UTF8, and will panic otherwise. As of now the actual map-data is not extracted.

If you want to parse a file directly see parse_from_file.